#ifndef SETTINGSDIALOG_H
#define SETTINGSDIALOG_H

#include <QDialog>
#include <QString>

namespace Ui {
    class SettingsDialog;
}

class SettingsDialog : public QDialog
{
    Q_OBJECT

public:
    explicit SettingsDialog(QWidget *parent = 0);
    ~SettingsDialog();

    static QString AUTO_ROTATE;
    static QString TRIGGER;
    static QString TRIGGER_COMMAND;
    static QString TRIGGER_COUNT;
    static QString TRIGGER_VALUE;

    void accept();

private:
    Ui::SettingsDialog *ui;
};

#endif // SETTINGSDIALOG_H
